# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mm_mamba']

package_data = \
{'': ['*']}

install_requires = \
['einops', 'torch==2.1.2', 'zetascale==1.4.0']

setup_kwargs = {
    'name': 'mmm-zeta',
    'version': '0.1.0',
    'description': 'MMM - Pytorch',
    'long_description': '[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)\n\n# Multi Modal Mamba - [MMM]\nMulti Modal Mamba (MMM) is an all-new AI model that integrates Vision Transformer (ViT) and Mamba, creating a high-performance multi-modal model. MMM is built on Zeta, a minimalist yet powerful AI framework, designed to streamline and enhance machine learning model management. \n\nThe capacity to process and interpret multiple data types concurrently is essential, the world isn\'t 1dimensional. MMM addresses this need by leveraging the capabilities of Vision Transformer and Mamba, enabling efficient handling of both text and image data. This makes MMM a versatile solution for a broad spectrum of AI tasks. MMM stands out for its significant speed and efficiency improvements over traditional transformer architectures, such as GPT-4 and LLAMA. This enhancement allows MMM to deliver high-quality results without sacrificing performance, making it an optimal choice for real-time data processing and complex AI algorithm execution. A key feature of MMM is its proficiency in processing extremely long sequences.\n\nThis capability is particularly beneficial for tasks that involve substantial data volumes or necessitate a comprehensive understanding of context, such as natural language processing or image recognition. With MMM, you\'re not just adopting a state-of-the-art AI model. You\'re integrating a fast, efficient, and robust tool that is equipped to meet the demands of contemporary AI tasks. Experience the power and versatility of Multi Modal Mamba - MMM now!\n\n## Install\n`pip3 install mmm-zeta`\n\n\n## Usage\n\n### `MultiModalMambaBlock`\n\n\n```python\n# Import the necessary libraries\nimport torch \nfrom torch import nn\nfrom mm_mamba import MultiModalMambaBlock\n\n# Create some random input tensors\nx = torch.randn(1, 16, 64)  # Tensor with shape (batch_size, sequence_length, feature_dim)\ny = torch.randn(1, 3, 64, 64)  # Tensor with shape (batch_size, num_channels, image_height, image_width)\n\n# Create an instance of the MultiModalMambaBlock model\nmodel = MultiModalMambaBlock(\n    dim = 64,  # Dimension of the token embeddings\n    depth = 5,  # Number of transformer layers\n    dropout = 0.1,  # Dropout probability\n    heads = 4,  # Number of attention heads\n    d_state = 16,  # Dimension of the state embeddings\n    image_size = 64,  # Size of the input image\n    patch_size = 16,  # Size of each image patch\n    encoder_dim = 64,  # Dimension of the encoder token embeddings\n    encoder_depth = 5,  # Number of encoder transformer layers\n    encoder_heads = 4,  # Number of encoder attention heads\n    fusion_method="mlp",\n)\n\n# Pass the input tensors through the model\nout = model(x, y)\n\n# Print the shape of the output tensor\nprint(out.shape)\n\n```\n\n\n### `MMM`, Ready to Train Model\n- Flexibility in Data Types: The MMM model can handle both text and image data simultaneously. This allows it to be trained on a wider variety of datasets and tasks, including those that require understanding of both text and image data.\n\n- Customizable Architecture: The MMM model has numerous parameters such as depth, dropout, heads, d_state, image_size, patch_size, encoder_dim, encoder_depth, encoder_heads, and fusion_method. These parameters can be tuned according to the specific requirements of the task at hand, allowing for a high degree of customization in the model architecture.\n\n- Option to Return Embeddings: The MMM model has a return_embeddings option. When set to True, the model will return the embeddings instead of the final output. This can be useful for tasks that require access to the intermediate representations learned by the model, such as transfer learning or feature extraction tasks.\n\n```python\nimport torch  # Import the torch library\n\n# Import the MMM model from the mm_mamba module\nfrom mm_mamba import MMM\n\n# Generate a random tensor \'x\' of size (1, 224) with random elements between 0 and 10000\nx = torch.randint(0, 10000, (1, 196))\n\n# Generate a random image tensor \'img\' of size (1, 3, 224, 224)\nimg = torch.randn(1, 3, 224, 224)\n\n# Create a MMM model object with the following parameters:\nmodel = MMM(\n    vocab_size=10000,\n    dim=512,\n    depth=6,\n    dropout=0.1,\n    heads=8,\n    d_state=512,\n    image_size=224,\n    patch_size=16,\n    encoder_dim=512,\n    encoder_depth=6,\n    encoder_heads=8,\n    fusion_method="mlp",\n    return_embeddings=False,\n    post_fuse_norm=True,\n)\n\n# Pass the tensor \'x\' and \'img\' through the model and store the output in \'out\'\nout = model(x, img)\n\n# Print the shape of the output tensor \'out\'\nprint(out.shape)\n```\n\n# Real-World Deployment\n\nAre you an enterprise looking to leverage the power of AI? Do you want to integrate state-of-the-art models into your workflow? Look no further!\n\nMulti Modal Mamba (MMM) is a cutting-edge AI model that fuses Vision Transformer (ViT) with Mamba, providing a fast, agile, and high-performance solution for your multi-modal needs. \n\nBut that\'s not all! With Zeta, our simple yet powerful AI framework, you can easily customize and fine-tune MMM to perfectly fit your unique quality standards. \n\nWhether you\'re dealing with text, images, or both, MMM has got you covered. With its deep configuration and multiple fusion layers, you can handle complex AI tasks with ease and efficiency.\n\n### :star2: Why Choose Multi Modal Mamba?\n\n- **Versatile**: Handle both text and image data with a single model.\n- **Powerful**: Leverage the power of Vision Transformer and Mamba.\n- **Customizable**: Fine-tune the model to your specific needs with Zeta.\n- **Efficient**: Achieve high performance without compromising on speed.\n\nDon\'t let the complexities of AI slow you down. Choose Multi Modal Mamba and stay ahead of the curve!\n\n[Contact us here](https://calendly.com/swarm-corp/30min) today to learn how you can integrate Multi Modal Mamba into your workflow and supercharge your AI capabilities!\n\n---\n\n\n# License\nMIT\n\n\n\n',
    'author': 'Kye Gomez',
    'author_email': 'kye@apac.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/kyegomez/MultiModalMamba',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
